==> adams-pdf-0.4.5-sources.jar: adams/gui/tools/previewbrowser/PDFHandler.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PDFHandler.java
 * Copyright (C) 2011-2012 University of Waikato, Hamilton, New Zealand
 */
package adams.gui.tools.previewbrowser;

import java.io.File;

import adams.core.CleanUpHandler;
import adams.core.io.JPod;
import adams.gui.visualization.pdf.PDFPanel;
import de.intarsys.pdf.pd.PDDocument;

/**
 <!-- globalinfo-start -->
 * Displays the content of PDF files as plain text.
 * <p/>
 <!-- globalinfo-end -->
 *
 <!-- options-start -->
 * Valid options are: <p/>
 *
 * <pre>-D &lt;int&gt; (property: debugLevel)
 * &nbsp;&nbsp;&nbsp;The greater the number the more additional info the scheme may output to
 * &nbsp;&nbsp;&nbsp;the console (0 = off).
 * &nbsp;&nbsp;&nbsp;default: 0
 * &nbsp;&nbsp;&nbsp;minimum: 0
 * </pre>
 *
 <!-- options-end -->
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 5662 $
 */
public class PDFHandler
  extends AbstractContentHandler
  implements CleanUpHandler {

  /** for serialization. */
  private static final long serialVersionUID = -1036622788944128074L;

  /** the current PDF document. */
  protected PDDocument m_Document;

  /**
   * Returns a string describing the object.
   *
   * @return 			a description suitable for displaying in the gui
   */
  @Override
  public String globalInfo() {
    return "Displays the content of PDF files.";
  }

  /**
   * Returns the list of extensions (without dot) that this handler can
   * take care of.
   *
   * @return		the list of extensions (no dot)
   */
  @Override
  public String[] getExtensions() {
    return new String[]{"pdf"};
  }

  /**
   * Creates the actual view.
   *
   * @param file	the file to create the view for
   * @return		the view
   */
  @Override
  protected PreviewPanel createPreview(File file) {
    PDFPanel	result;

    m_Document = JPod.load(file);
    result     = new PDFPanel();
    result.setDocument(m_Document);

    return new PreviewPanel(result);
  }

  /**
   * Cleans up data structures, frees up memory.
   */
  public void cleanUp() {
    JPod.close(m_Document);
  }
}

==> adams-pdf-0.4.11-sources.jar: adams/gui/tools/previewbrowser/PDFHandler.java <==
/*
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * PDFHandler.java
 * Copyright (C) 2011-2012 University of Waikato, Hamilton, New Zealand
 */
package adams.gui.tools.previewbrowser;

import java.io.File;

import adams.core.CleanUpHandler;
import adams.core.io.JPod;
import adams.gui.visualization.pdf.PDFPanel;
import de.intarsys.pdf.pd.PDDocument;

/**
 <!-- globalinfo-start -->
 * Displays the content of PDF files as plain text.
 * <br><br>
 <!-- globalinfo-end -->
 *
 <!-- options-start -->
 * Valid options are: <br><br>
 *
 * <pre>-D &lt;int&gt; (property: debugLevel)
 * &nbsp;&nbsp;&nbsp;The greater the number the more additional info the scheme may output to
 * &nbsp;&nbsp;&nbsp;the console (0 = off).
 * &nbsp;&nbsp;&nbsp;default: 0
 * &nbsp;&nbsp;&nbsp;minimum: 0
 * </pre>
 *
 <!-- options-end -->
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 10824 $
 */
public class PDFHandler
  extends AbstractContentHandler
  implements CleanUpHandler {

  /** for serialization. */
  private static final long serialVersionUID = -1036622788944128074L;

  /** the current PDF document. */
  protected PDDocument m_Document;

  /**
   * Returns a string describing the object.
   *
   * @return 			a description suitable for displaying in the gui
   */
  @Override
  public String globalInfo() {
    return "Displays the content of PDF files.";
  }

  /**
   * Returns the list of extensions (without dot) that this handler can
   * take care of.
   *
   * @return		the list of extensions (no dot)
   */
  @Override
  public String[] getExtensions() {
    return new String[]{"pdf"};
  }

  /**
   * Creates the actual view.
   *
   * @param file	the file to create the view for
   * @return		the view
   */
  @Override
  protected PreviewPanel createPreview(File file) {
    PDFPanel	result;

    m_Document = JPod.load(file);
    result     = new PDFPanel();
    result.setDocument(m_Document);

    return new PreviewPanel(result);
  }

  /**
   * Cleans up data structures, frees up memory.
   */
  public void cleanUp() {
    JPod.close(m_Document);
  }
}
